"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var http_1 = require("@angular/http");
var webcmpmetadata_1 = require("../webcmpmetadata/webcmpmetadata");
var metadata_selector_1 = require("@gsp-lcm/metadata-selector");
var operators_1 = require("rxjs/operators");
var typescript_parser_1 = require("typescript-parser");
var services_1 = require("@farris/ide-devkit/services");
var core_1 = require("@angular/core");
var WebCmpExternalService = (function () {
    function WebCmpExternalService(cache, metadataService, http, url) {
        this.cache = cache;
        this.metadataService = metadataService;
        this.http = http;
        this.url = url;
        this.Server_IP = (this.url === null || this.url === undefined) ? 'http://10.24.19.140:5000' : this.url;
    }
    WebCmpExternalService.prototype.saveTsCode = function (code, url) {
        return this.http.post(this.Server_IP + url, code).toPromise();
    };
    WebCmpExternalService.prototype.getTsCode = function (url) {
        return this.http.get(this.Server_IP + url).toPromise();
    };
    /**
     * 重新发布Web方法构件
     * @param tsUri ts文件的路径
     * @param sourceCode ts文件的源码
     */
    /**
       * 重新发布Web方法构件
       * @param tsUri ts文件的路径
       * @param sourceCode ts文件的源码
       */
    WebCmpExternalService.prototype.RepublishWebCmp = /**
       * 重新发布Web方法构件
       * @param tsUri ts文件的路径
       * @param sourceCode ts文件的源码
       */
    function (tsUri, sourceCode) {
        var _this = this;
        var parser = new typescript_parser_1.TypescriptParser();
        parser.parseSource(sourceCode).then(function (response) {
            return _this.parseAndResaveMetadata(tsUri, response);
        });
    };
    WebCmpExternalService.prototype.parseAndResaveMetadata = function (tsUri, file) {
        var _this = this;
        if (file.declarations.length > 1) {
            alert("最多允许声明一个class，请检查ts代码");
            return;
        }
        var className = file.declarations[0].name;
        var operations = new Array();
        for (var _i = 0, _a = file.declarations; _i < _a.length; _i++) {
            var c = _a[_i];
            for (var _b = 0, _c = c.methods; _b < _c.length; _b++) {
                var m = _c[_b];
                var method = new webcmpmetadata_1.Operation();
                method.Parameters = new Array();
                method.Id = this.getGuid();
                method.Name = m.name;
                method.Code = m.name;
                for (var _d = 0, _e = m.parameters; _d < _e.length; _d++) {
                    var p = _e[_d];
                    var param = new webcmpmetadata_1.Parameter();
                    param.Id = this.getGuid();
                    param.Name = p.name;
                    param.Code = p.name;
                    param.ParameterType = p.type ? p.type : "any";
                    param.IsRetVal = false;
                    method.Parameters.push(param);
                }
                if (m.type || m.type == undefined) {
                    var ret = new webcmpmetadata_1.Parameter();
                    ret.Id = this.getGuid();
                    ret.Name = "returnValue";
                    ret.Code = "returnValue";
                    ret.ParameterType = m.type ? m.type : "any";
                    ret.IsRetVal = true;
                    method.Parameters.push(ret);
                }
                operations.push(method);
            }
        }
        var webCmpUri = tsUri.replace(".ts", ".webcmp");
        var fileName = webCmpUri.substring(webCmpUri.lastIndexOf('/') + 1);
        var filePath = webCmpUri.substring(1, webCmpUri.lastIndexOf('/'));
        this.metadataService.LoadMetadata(fileName, filePath).subscribe(function (dto) {
            var webCmpMetadata;
            webCmpMetadata = JSON.parse(dto.content);
            webCmpMetadata.ClassName = className;
            webCmpMetadata.Operations = operations;
            var stringcontent = JSON.stringify(webCmpMetadata);
            dto.content = stringcontent;
            var sessionId = _this.cache.get('sessionId');
            _this.metadataService.SaveMetadata(dto, sessionId).subscribe(function (response) {
                if (response.status == 200) {
                    alert('重新发布Web构件成功');
                }
                else {
                    alert("重新发布Web构件失败");
                }
            });
        });
    };
    /**
     * 根据元数据Uri获取Web方法构件实体
     * @param metadataUri web方法构件Uri
     */
    /**
       * 根据元数据Uri获取Web方法构件实体
       * @param metadataUri web方法构件Uri
       */
    WebCmpExternalService.prototype.getWebCmpMetadata = /**
       * 根据元数据Uri获取Web方法构件实体
       * @param metadataUri web方法构件Uri
       */
    function (metadataUri) {
        var fileName = metadataUri.substring(metadataUri.lastIndexOf('/') + 1);
        var filePath = metadataUri.substring(1, metadataUri.lastIndexOf('/'));
        return this.metadataService.LoadMetadata(fileName, filePath).pipe(operators_1.map(function (dto) {
            return JSON.parse(dto.content);
        }));
    };
    //Guid生成Id
    //Guid生成Id
    WebCmpExternalService.prototype.getGuid = 
    //Guid生成Id
    function () {
        return (this.s4() + this.s4() + "-" + this.s4() + "-" + this.s4() + "-" + this.s4() + "-" + this.s4() + this.s4() + this.s4());
    };
    WebCmpExternalService.prototype.s4 = function () {
        return (((1 + Math.random()) * 0x10000) | 0).toString(16).substring(1);
    };
    WebCmpExternalService.decorators = [
        { type: core_1.Injectable },
    ];
    /** @nocollapse */
    WebCmpExternalService.ctorParameters = function () { return [
        { type: services_1.CacheService, },
        { type: metadata_selector_1.GSPMetadataService, },
        { type: http_1.Http, },
        { type: undefined, decorators: [{ type: core_1.Inject, args: ['url',] },] },
    ]; };
    return WebCmpExternalService;
}());
exports.WebCmpExternalService = WebCmpExternalService;
//# sourceMappingURL=webcmpexternalservice.js.map